@@ -17,12 +17,12 @@
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **
-** @(#)$Id: hash_func.c,v 1.4 2000/01/27 03:48:55 klmitch Exp $
+** @(#)$Id: hash_func.c,v 1.5 2000/12/07 16:48:36 klmitch Exp $
 */
 #include "hash.h"
 #include "hash_int.h"
 
-RCSTAG("@(#)$Id: hash_func.c,v 1.4 2000/01/27 03:48:55 klmitch Exp $");
+RCSTAG("@(#)$Id: hash_func.c,v 1.5 2000/12/07 16:48:36 klmitch Exp $");
 
 _h_ul
 _hash_func(hash_tab *table, hash_key *key, _h_ul modulus)
@@ -31,7 +31,9 @@ _hash_func(hash_tab *table, hash_key *key, _h_ul modulus)
   int i;
 
   for (i = 0; i < key->hk_length; i++)
-    hash += hash + key->hk_key[i];
+    hash = (hash * 257) + key->hk_key[i];
+  /* New hash function courtesy of Nemesi */
+  /* hash += hash + key->hk_key[i]; */
 
   return hash % modulus;
 }
