@@ -17,27 +17,36 @@
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **
-** @(#)$Id: ht_iter.c,v 1.3 2000/01/27 03:48:56 klmitch Exp $
+** @(#)$Id: ht_iter.c,v 1.5 2000/08/02 19:34:02 klmitch Exp $
 */
 #include "hash.h"
 #include "hash_int.h"
 
-RCSTAG("@(#)$Id: ht_iter.c,v 1.3 2000/01/27 03:48:56 klmitch Exp $");
+RCSTAG("@(#)$Id: ht_iter.c,v 1.5 2000/08/02 19:34:02 klmitch Exp $");
 
 _h_ul
 ht_iter(hash_tab *table, hash_iter iter_func, void *extra)
 {
   _h_ul retval;
   int i;
-  hash_ent *entry;
+  hash_ent *entry, *next;
 
   if (!ht_verify(table) || !iter_func)
     return HASH_ERR_BADARGS;
 
+  table->ht_flags |= HASH_FLAGS_FREEZE;
+
   for (i = 0; i < table->ht_modulus; i++)
-    for (entry = table->ht_table[i]; entry; entry = entry->he_next)
+    for (entry = table->ht_table[i]; entry; entry = next) {
+      next = entry->he_next;
       if ((retval = (*iter_func)(table, entry, extra)))
 	return retval;
+    }
+
+  table->ht_flags &= ~HASH_FLAGS_FREEZE;
+  if (table->ht_flags & HASH_FLAGS_RESIZE)
+    if ((retval = ht_resize(table, table->ht_count)))
+      return retval;
 
   return 0;
 }
